package com.landray.kmss.sys.attachment.service.spring;

import net.sf.json.JSONObject;
import com.landray.kmss.sys.attachment.util.SysAttViewerUtil;
import java.net.URLEncoder;
import com.landray.kmss.util.UserUtil;
import com.landray.kmss.sys.attachment.model.SysAttMain;
import com.landray.kmss.util.ResourceUtil;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;

public class SysAttMainFoxitBuilder
{
    private static final Logger logger;
    
    static {
        logger = LoggerFactory.getLogger(SysAttMainFoxitBuilder.class);
    }
    
    public SysAttMainFoxitBuilder creatFoxitAuthorization(final HttpServletRequest request) {
        request.setAttribute("licenseSN", (Object)ResourceUtil.getKmssConfigString("sys.foxit.license.sn"));
        request.setAttribute("licenseKey", (Object)ResourceUtil.getKmssConfigString("sys.foxit.license.key"));
        return this;
    }
    
    public SysAttMainFoxitBuilder createSysAuthorization(final HttpServletRequest request, final SysAttMain sysAttMain) {
        final boolean canPrint = UserUtil.checkAuthentication("/sys/attachment/sys_att_main/sysAttMain.do?method=print&fdId=" + sysAttMain.getFdId(), "GET");
        request.setAttribute("canPrint", (Object)canPrint);
        final boolean download = UserUtil.checkAuthentication("/sys/attachment/sys_att_main/sysAttMain.do?method=download&fdId=" + sysAttMain.getFdId(), "GET");
        request.setAttribute("download", (Object)download);
        return this;
    }
    
    public SysAttMainFoxitBuilder createSysFileInfo(final HttpServletRequest request, final SysAttMain sysAttMain, final String sign, final long expires) throws Exception {
        String urlPrefix = ResourceUtil.getKmssConfigString("kmss.urlPrefix");
        if (urlPrefix.endsWith("/")) {
            urlPrefix = urlPrefix.substring(0, urlPrefix.lastIndexOf("/"));
        }
        if (SysAttMainFoxitBuilder.logger.isDebugEnabled()) {
            SysAttMainFoxitBuilder.logger.debug("系统地址:" + urlPrefix);
        }
        final String downLoadUrl = String.valueOf(urlPrefix) + "/sys/attachment/sys_att_main/downloadFile.jsp?fdId=" + sysAttMain.getFdId() + "&Expires=" + expires + "&Signature=" + sign + "&reqType=rest&filename=" + URLEncoder.encode(sysAttMain.getFdFileName(), "utf-8");
        if (SysAttMainFoxitBuilder.logger.isDebugEnabled()) {
            SysAttMainFoxitBuilder.logger.debug("下载地址:" + downLoadUrl);
        }
        request.setAttribute("downLoadUrl", (Object)downLoadUrl);
        request.setAttribute("filename", (Object)sysAttMain.getFdFileName());
        request.setAttribute("fdId", (Object)sysAttMain.getFdId());
        request.setAttribute("fileSize", (Object)SysAttViewerUtil.convertFileSize(sysAttMain.getFdSize()));
        return this;
    }
    
    public SysAttMainFoxitBuilder createWaterInfo(final HttpServletRequest request) {
        final JSONObject watermarkCfg = SysAttViewerUtil.getWaterMarkConfigInDB(Boolean.valueOf(true));
        final Boolean showWordWater = watermarkCfg.get("markWordVar") != null && "true".equals(watermarkCfg.get("showWaterMark")) && "word".equals(watermarkCfg.get("markType"));
        final Boolean showPictureWater = watermarkCfg.get("markWordVar") != null && "true".equals(watermarkCfg.get("showWaterMark")) && "pic".equals(watermarkCfg.get("markType"));
        final SysAttMainWaterInfoBuilder sysAttMainWaterInfoBuilder = new SysAttMainWaterInfoBuilder();
        final org.json.simple.JSONObject waterMarkInfo = sysAttMainWaterInfoBuilder.addBaseData(watermarkCfg).addWordWaterData(request, watermarkCfg, showWordWater).addPictureWaterData(request, watermarkCfg, showPictureWater).build();
        request.setAttribute("markWordVar", (Object)waterMarkInfo.toString().replaceAll("\"", "'"));
        return this;
    }
    
    public SysAttMainFoxitBuilder createOthersInfo(final HttpServletRequest request) {
        request.setAttribute("isMobile", (Object)this.isMobileRequest(request));
        return this;
    }
    
    public boolean isMobileRequest(final HttpServletRequest request) {
        final String userAgent = request.getHeader("user-agent");
        return userAgent.indexOf("Android") != -1 || (userAgent.indexOf("iPhone") != -1 || userAgent.indexOf("iPad") != -1);
    }
}
